@@ -11,10 +11,10 @@ def acc(y_pred, y):
 
 class TweetyNetModel(vak.Model):
     @classmethod
-    def from_config(cls, config):
+    def from_config(cls, config, logger=None):
         network = TweetyNet(**config['network'])
         loss = torch.nn.CrossEntropyLoss(**config['loss'])
-        optimizer = torch.optim.SGD(params=network.parameters(), **config['optimizer'])
+        optimizer = torch.optim.Adam(params=network.parameters(), **config['optimizer'])
         metrics = {'acc': vak.metrics.Accuracy(),
                    'loss': torch.nn.CrossEntropyLoss()}
-        return cls(network=network, optimizer=optimizer, loss=loss, metrics=metrics)
+        return cls(network=network, optimizer=optimizer, loss=loss, metrics=metrics, logger=logger)
